<?php
/*
	Plugin Name: Style the Toolbar
	Plugin URI: https://wordpress.org/plugins/style-the-toolbar/
	Description: Changes the colour of the WordPress toolbar on the front-end to match the theme within the admin area.
	Author: Daniel James
	Version: 1.2
	Author URI: https://www.danieltj.co.uk/
*/

/**
 * The core plugin function.
 * 
 * @package Style_the_Toolbar
 * @version 1.2
 */

// Prevent direct access to the file.
if ( function_exists( 'add_action' ) ) {

	// Do the plugin stuffs.
	function dtj_style_the_toolbar() {
		
		// Check if the current user is logged in.
		if ( ( is_user_logged_in() ) && ( is_admin_bar_showing() ) ) {

			// Get the current theme for the user.
			$dtj_user_colour = get_user_meta(get_current_user_id(), 'admin_color', true);

			// Reset load style variable for later.
			$dtj_load_style = false;

			// Check which type of file we need to use for the colour scheme.
			if ( is_rtl() ) {

				// Determine whether the RTL minified stylesheet exists.
				if ( file_exists( "wp-admin/css/colors/" . $dtj_user_colour . "/colors-rtl.min.css" ) ) {

					$dtj_colour_file = "colors-rtl.min.css";

					$dtj_load_style = true;

				} else {

					// Determine whether the RTL stylesheet exists.
					if ( file_exists( "wp-admin/css/colors/" . $dtj_user_colour . "/colors-rtl.css" ) ) {

						$dtj_colour_file = "colors-rtl.css";

						$dtj_load_style = true;

					} else {

						// Determine whether the minified stylesheet exists.
						if ( file_exists( "wp-admin/css/colors/" . $dtj_user_colour . "/colors.min.css" ) ) {

							$dtj_colour_file = "colors.min.css";

							$dtj_load_style = true;

						} else {

							// Determine whether the stylesheet exists.
							if ( file_exists( "wp-admin/css/colors/" . $dtj_user_colour . "/colors.css" ) ) {

								$dtj_colour_file = "colors.css";

								$dtj_load_style = true;

							} else {

								// A suitable colour CSS file wasn't found, don't do anything.

							}

						}

					}

				}

			} else {

				// Determine whether the minified stylesheet exists.
				if ( file_exists( "wp-admin/css/colors/" . $dtj_user_colour . "/colors.min.css" ) ) {

					$dtj_colour_file = "colors.min.css";

					$dtj_load_style = true;

				} else {

					// Determine whether the stylesheet exists.
					if ( file_exists( "wp-admin/css/colors/" . $dtj_user_colour . "/colors.css" ) ) {

						$dtj_colour_file = "colors.css";

						$dtj_load_style = true;

					} else {

						// A suitable colour CSS file wasn't found, don't do anything.

					}

				}

			}

			// See if we have a file to include.
			if ( $dtj_load_style !== false ) {

				// Get the URL path to the current theme.
				$dtj_colour_path = admin_url('css/colors/' . $dtj_user_colour . "/" . $dtj_colour_file);

				// Enqueue the file to the styles list.
				wp_enqueue_style('dtj-toolbar-colour', $dtj_colour_path, '', '1.2');

			}

		}

	}

	// Add the stylesheet to the page for output.
	add_action('wp_enqueue_scripts', 'dtj_style_the_toolbar');

} else {

	// No file peeping please.
	exit;

}
